View Source Guardian.DB.Sweeper (Guardian.DB v3.0.0)
A GenServer that periodically checks for, and expires, tokens from storage.
To leverage the automated Sweeper functionality update your project's Application file to include the following child in your supervision tree:
interval- The interval between db sweeps to remove old tokens, in milliseconds. Defaults to 1 hour.
Example
worker(Guardian.DB.Sweeper, [interval: 60 * 60 * 1000])
Summary
Functions
Returns a specification to start this module under a supervisor.
Manually trigger a database purge of expired tokens. Also resets the current scheduled work.
Reset the purge timer.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Manually trigger a database purge of expired tokens. Also resets the current scheduled work.
Reset the purge timer.